#
# spec file for package imv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           imv
Version:        4.5.0
Release:        bp160.2.4
Summary:        Image viewer for X11/Wayland
License:        GPL-2.0-or-later AND MIT
Group:          Productivity/Graphics/Viewers
URL:            https://git.sr.ht/~exec64/imv
Source:         https://git.sr.ht/~exec64/imv/archive/v%{version}.tar.gz
Patch0:         imv-link-icu-uc.patch
BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  freeimage-devel
BuildRequires:  libicu-devel
BuildRequires:  libinih-devel
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(cmocka)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.44
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libturbojpeg)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)

%description
imv is a command line image viewer intended for use with tiling window managers.

%prep
%autosetup -n %{name}-v%{version}

%build
%meson -Dlibnsgif=disabled
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-dir.desktop
%{_mandir}/man?/%{name}*
%{_sysconfdir}/%{name}_config

%changelog
* Mon Mar 17 2025 Matej Cepl <mcepl@cepl.eu>
- Add missing dependencies: cmake, pkgconfig(egl), pkgconfig(gl),
  and pkgconfig(glu).
* Fri Nov 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- imv-link-icu-uc.patch: specify icu-uc as dependency instead of
  icu-io: IMV does not use the Stream & I/O parts of ICU, the
  common library is sufficient (and required).
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.5.0:
  * Add new jpgxl backend
  * Added -W and -H arguments to configure initial dimensions
  * Fix utf8 in window titles
  * Fix some animated gifs showing as still images
  * Fix several crashes
  * Fixed new build warnings
  * Limit libnsgif to <1.0.0 to fix build
  * Update mime types
* Thu Jan 19 2023 llyyr <llyyr.public@gmail.com>
- Update to 4.4.0:
  * Fixed critical error "wl_window: fix buffer size not divisible by scale"
  * Added libgrapheme 2.0.0 as an alternative to icu
  * Added '-w' option to specify window title at startup
  * Added background rectangle behind the (possibly multiline) overlay text
  * Changed chequered pattern to only over the image area for transparent images not the whole viewport
  * Renamed imv-folder to imv-dir
  * Fixed slideshow not always pausing correctly
  * Fixed imv-dir showing as a duplicate imv in its desktop file
  * Fixed whitespace bug in expanded title text
  * Made imv-dir fall back to imv behaviour when given too many arguments
  * Improved handling of paths from stdin
  * Minor documentation and changelog improvements
* Tue Mar  8 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to 4.3.1:
  * Fix segfault when used with latest wlroots
- Update source URL from github to https://git.sr.ht/~exec64/imv
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.3.0:
  * Give freeimage backend preceedence over libjpeg
  * Fix lack of X11 window deletion event handling
  * Scale fonts correctly for high-DPI wayland
  * Suppress annoying TIFF error messages
  * Fix missing -lm dependency for imv-msg
  * Fix image skipping when reading slow filesystems
  * Add a contrib directory
  * Add contrib/imv-folder
  * Fix zoom speed dependence on buffer/image width
  * Improve stat error handling when loading directories
  * Fix double-free when backend libjpeg is used
  * Fix -n option not working for symbolic links
  * List image/heif as a supported mime type
  * Fix flickering bug in high-DPI wayland
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.2.0:
  * Switched to meson build system
  * Added HEIF backend
  * Added rotate and flip commands
  * Added colour support for overlay
  * Added some missing command/config documentation
  * Read directories in alphabetical order
  * Fixed several memory leaks
  * Improved compatibility with non glibc systems
  * Fixed several window management bugs for Wayland
  * Fixed bug when selecting first/last image
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.1.0:
  * Added libsngif backend
  * Added command history to console
  * Added proper UTF-8 support to the console
  * Fixed name of libjpeg-turbo backend
  * Fixed reading images from stdin
  * Increased maximum supported PNG file size
  * Added Keywords to imv.desktop
  * Set NoDisplay in imv.desktop
  * Simplified async logic in backends
  * Fixed typo in manpages
  * Fixed name of the LGPL
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.0.1:
  * Documented default binds in man page
  * Added icon to imv.desktop
  * Added builtin aliases to provide backwards compatibility for removed commands
  * Added warning when legacy bind syntax is detected
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.0.0:
  * Fixed keyboard layout handling, changing bind syntax
  * Renamed many commands (select_rel -> next/prev, select_abs -> goto, etc.)
  * Temporarily removed autoresize option
  * Dropped SDL2 dependency, implementing Wayland and X11 support natively
    through imv-wayland and imv-x11 binaries
  * Added support for displaying SVGs at native resolution regardless of zoom
    level
  * Added hidpi support on Wayland
  * Added '-c' argument to specify commands to run at startup
  * Added 'bind' command to add new binds at runtime
  * Added 'background' command to change background colour at runtime
  * Added 'upscaling' command to modify upscaling method at runtime
  * Added optional argument to close command to specify an index or all images
  * Added initial_pan option to configure which part of an image is initially
    focused on
  * Added support for aliases passing arguments to underlying their commands
  * Added imv-msg program to send commands to a running instance of imv
  * Added $imv_pid environment variable
  * Allowed imv to remain open with no images open
  * Improved unicode support in overlay
  * Fixed typo in $imv_slideshow_duration environment variable
  * Added new crop scaling method, which will zoom in until an image completely
    fills the window
  * Fixed a bug where 16-bit greyscale images would not load
  * Fixed a memory corruption bug in generic list implementation
  * Fixed several memory leaks
* Mon Jul  1 2019 mvetter@suse.com
- Update to 3.1.2:
  * Fix manpage packaging regression introduced in v3.1.1
- Remove imv-fixbuild.patch: upstreamed
* Mon Jun 24 2019 mvetter@suse.com
- Update to 3.1.1:
  * Adjusted Makefile to improve packaging on BSDs
- Add imv-fixbuild.patch: fixing build by creating man dirs
* Tue Jun 18 2019 mvetter@suse.com
- Update to 3.1.0:
  * Added support for multiple image loaders, allowing imv to use libraries other
    than FreeImage. This adds support for SVGs, and in the future, other formats
    as required.
  * Loaders added for libpng, libtiff, librsvg, libturbojpeg.
  * Added support for binding multiple commands to a single key
  * Support for hidpi rendering with SDL >= 2.0.10
  * Added -v flag to show version number
  * Allow 'Escape' to be bound, changing bind abort sequence to 2x'Escape'
  * Fixed bug where path list from stdin would sometime be truncated
  * New releases only published under the MIT license, with FreeImage optionally
    used under the FIPL
  * Fixed several memory leaks
  * Miscellaneous code cleanup and documentation fixes
* Mon Jan 28 2019 mvetter@suse.com
- Create package imv 3.0.0 for openSUSE
